# `narwhals.DataFrame`

::: narwhals.dataframe.DataFrame
    handler: python
    options:
      members:
        - to_pandas
        - to_numpy
        - shape
        - __getitem__
        - to_dict
        - schema
        - columns
        - with_columns
        - select
        - rename
        - head
        - drop
        - unique
        - filter
        - group_by
        - sort
        - join
      show_root_heading: false
      show_source: false
      show_bases: false
